aboutsummaryrefslogtreecommitdiff
path: root/src/processor/stackwalker_x86.cc
diff options
context:
space:
mode:
Diffstat (limited to 'src/processor/stackwalker_x86.cc')
-rw-r--r--src/processor/stackwalker_x86.cc12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/processor/stackwalker_x86.cc b/src/processor/stackwalker_x86.cc
index 444746cd..2276374a 100644
--- a/src/processor/stackwalker_x86.cc
+++ b/src/processor/stackwalker_x86.cc
@@ -37,13 +37,13 @@
#include "processor/postfix_evaluator-inl.h"
#include "processor/stackwalker_x86.h"
-#include "google_airbag/processor/call_stack.h"
-#include "google_airbag/processor/memory_region.h"
-#include "google_airbag/processor/stack_frame_cpu.h"
+#include "google_breakpad/processor/call_stack.h"
+#include "google_breakpad/processor/memory_region.h"
+#include "google_breakpad/processor/stack_frame_cpu.h"
#include "processor/linked_ptr.h"
#include "processor/stack_frame_info.h"
-namespace google_airbag {
+namespace google_breakpad {
StackwalkerX86::StackwalkerX86(const SystemInfo *system_info,
@@ -134,7 +134,7 @@ StackFrame* StackwalkerX86::GetCallerFrame(
// Set up the dictionary for the PostfixEvaluator. %ebp and %esp are used
// in each program string, and their previous values are known, so set them
// here. .cbCalleeParams is an Airbag extension that allows us to use
// the PostfixEvaluator engine when certain types of debugging information
// are present without having to write the constants into the program string
// as literals.
@@ -312,4 +312,4 @@ StackFrame* StackwalkerX86::GetCallerFrame(
}
-} // namespace google_airbag
+} // namespace google_breakpad
@@ -134,7 +134,7 @@ StackFrame* StackwalkerX86::GetCallerFrame(
// Set up the dictionary for the PostfixEvaluator. %ebp and %esp are used
// in each program string, and their previous values are known, so set them
- // here. .cbCalleeParams is an Airbag extension that allows us to use
+ // here. .cbCalleeParams is an Breakpad extension that allows us to use
// the PostfixEvaluator engine when certain types of debugging information
// are present without having to write the constants into the program string